package com.ym.mec.web.controller;

import com.ym.mec.common.controller.BaseController;
import com.ym.mec.web.dal.dto.SubFeeSettingDto;
import com.ym.mec.web.dal.entity.MusicGroup;
import com.ym.mec.web.dal.page.MusicGroupQueryInfo;
import com.ym.mec.web.service.MusicGroupService;
import io.swagger.annotations.Api;
import io.swagger.annotations.ApiOperation;
import io.swagger.annotations.ApiParam;
import org.apache.commons.lang3.StringUtils;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.web.bind.annotation.*;

import java.util.Date;

@RequestMapping("musicGroup")
@Api(tags = "乐团服务")
@RestController
public class MusicGroupController extends BaseController {

    @Autowired
    private MusicGroupService musicGroupService;

    @ApiOperation(value = "新增乐团")
    @PostMapping("/add")
    public Object add(@RequestBody MusicGroup musicGroup){
        if(musicGroup != null){
            if(StringUtils.isNotEmpty(musicGroup.getPaymentMonths())){
                musicGroupService.add(musicGroup);
            }else {
                musicGroupService.insert(musicGroup);
            }
            return succeed();
        }
        return failed();
    }

    @ApiOperation(value = "删除乐团")
    @DeleteMapping("/del/{id}")
    public Object del(@ApiParam(value = "乐团编号", required = true) @PathVariable("id") String id){
        musicGroupService.delete(id);
        return succeed();
    }

    @ApiOperation(value = "修改乐团")
    @PutMapping("/update")
    public Object update(@RequestBody MusicGroup musicGroup){
        musicGroup.setUpdateTime(new Date());
        musicGroupService.update(musicGroup);
        return succeed();
    }

    @ApiOperation(value = "根据乐团编号查询乐团")
    @GetMapping("/get/{id}")
    public Object get(@ApiParam(value = "乐团编号", required = true) @PathVariable("id") String id){
        return succeed(musicGroupService.get(id));
    }

    @ApiOperation(value = "分页查询乐团列表")
    @PostMapping("/queryPage")
    public Object queryPage(@RequestBody MusicGroupQueryInfo queryInfo){
        return succeed(musicGroupService.queryPage(queryInfo));
    }

    @ApiOperation(value = "建团申请数据提交")
    @PostMapping("/createGroup")
    public Object createGroup(@RequestBody SubFeeSettingDto subFeeSettingDto){
        musicGroupService.createGroup(subFeeSettingDto);
        return succeed();
    }
}
