package com.ym.mec.web.service.impl;

import com.ym.mec.common.dal.BaseDAO;
import com.ym.mec.common.page.PageInfo;
import com.ym.mec.common.service.impl.BaseServiceImpl;
import com.ym.mec.util.collection.MapUtil;
import com.ym.mec.web.dal.dao.CourseScheduleDao;
import com.ym.mec.web.dal.dao.TeacherAttendanceDao;
import com.ym.mec.web.dal.dto.TeacherAttendanceDto;
import com.ym.mec.web.dal.dto.TeacherPersonalAttendanceDto;
import com.ym.mec.web.dal.entity.CourseSchedule;
import com.ym.mec.web.dal.entity.TeacherAttendance;
import com.ym.mec.web.dal.enums.CourseStatusEnum;
import com.ym.mec.web.dal.enums.ParamEnum;
import com.ym.mec.web.dal.enums.SignStatusEnum;
import com.ym.mec.web.dal.page.TeacherAttendanceQueryInfo;
import com.ym.mec.web.service.TeacherAttendanceService;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.stereotype.Service;

import java.text.ParseException;
import java.text.SimpleDateFormat;
import java.util.*;

@Service
public class TeacherAttendanceServiceImpl extends BaseServiceImpl<Long, TeacherAttendance>  implements TeacherAttendanceService {
	
	@Autowired
	private TeacherAttendanceDao teacherAttendanceDao;
	@Autowired
	private CourseScheduleDao courseScheduleDao;

	@Override
	public BaseDAO<Long, TeacherAttendance> getDAO() {
		return teacherAttendanceDao;
	}

	@Override
	public void addTeacherAttendanceRecord(TeacherAttendance teacherAttendance) {
		CourseSchedule courseSchedule=new CourseSchedule();
		TeacherAttendanceDto currentCourseDetail = courseScheduleDao.getCurrentCourseDetail(teacherAttendance.getCourseScheduleId());
		courseSchedule.setId(currentCourseDetail.getCourseScheduleId());
		Date date = new Date();
		if(teacherAttendance.getStatus()!= SignStatusEnum.YES_QUIT){
			StringBuilder startClassDateTimeString=new StringBuilder(new SimpleDateFormat("yyyy-MM-dd").format(currentCourseDetail.getClassDate()));
			startClassDateTimeString.append(" ");
			startClassDateTimeString.append(new SimpleDateFormat("HH:mm:ss").format(currentCourseDetail.getStartClassTime()));
			Date startClassTime = null;
			try {
				startClassTime = new SimpleDateFormat("yyyy-MM-dd HH:mm:ss")
						.parse(startClassDateTimeString.toString());
			} catch (ParseException e) {
				e.printStackTrace();
			}
			Long timeGap=(date.getTime()-startClassTime.getTime())/1000/60;
			if(timeGap<= ParamEnum.TEACHER_ATTENDANCE_TIME_GAP.getCode()){
				teacherAttendance.setStatus(SignStatusEnum.SIGN);
			}else{
				teacherAttendance.setStatus(SignStatusEnum.EXCEPTION);
			}
			courseSchedule.setStatus(CourseStatusEnum.UNDERWAY);
		}else{
			courseSchedule.setStatus(CourseStatusEnum.OVER);
		}
		courseScheduleDao.update(courseSchedule);
		teacherAttendance.setMusicGroupId(currentCourseDetail.getMusicGroupId());
		teacherAttendance.setSubjectId(currentCourseDetail.getSubjectId());
		teacherAttendance.setClassGroupId(currentCourseDetail.getClassId());
		teacherAttendance.setSignInTime(date);
		teacherAttendance.setCreateTime(date);
		teacherAttendanceDao.insert(teacherAttendance);
	}

	@Override
	public PageInfo getTeacherPersonalAttendances(TeacherAttendanceQueryInfo queryInfo) {
		PageInfo<TeacherPersonalAttendanceDto> pageInfo = new PageInfo<>(queryInfo.getPage(), queryInfo.getRows());
		Map<String, Object> params = new HashMap<String, Object>();
		MapUtil.populateMap(params, queryInfo);

		List<TeacherPersonalAttendanceDto> dataList = null;
		int count = teacherAttendanceDao.getTeacherPersonalAttendancesCount(params);
		if (count > 0) {
			pageInfo.setTotal(count);
			params.put("offset", pageInfo.getOffset());
			dataList = teacherAttendanceDao.getTeacherPersonalAttendances(params);
		}
		if (count == 0) {
			dataList = new ArrayList<>();
		}
		pageInfo.setRows(dataList);
		return pageInfo;
	}


}